@@ -1,4 +1,10 @@
 # JSON helper functions
+from django.http import HttpResponse
+
+try:
+    import simplejson as json
+except ImportError:
+    import json
 
 def JSONResponse(data, dump=True):
     return HttpResponse(
